PlaceDynamic

Trait PlaceDynamic 

pub trait PlaceDynamic {
    // Required method
    fn place_dynamic(&self, place: &mut Object);
}
The PlaceDynamic trait is used by derived implementations of FromDynamic to implement flattened conversions. Deriving FromDynamic for a struct will usually also derive PlaceDynamic for the same struct. You do not typically consume PlaceDynamic directly.

Required Methods

fn place_dynamic(&self, place: &mut Object)

Convert from Self to Value, by storing directly into the target Object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors