pub trait ToDynamic {
// Required method
fn to_dynamic(&self) -> Value;
}Expand description
The ToDynamic trait allows a type to emit a representation of itself as the Value type. This trait can be derived.
pub trait ToDynamic {
// Required method
fn to_dynamic(&self) -> Value;
}The ToDynamic trait allows a type to emit a representation of itself as the Value type. This trait can be derived.